@@ -1,7 +1,3 @@
-/*
- * ipconfig/ipconfig.h
- */
-
 #ifndef IPCONFIG_IPCONFIG_H
 #define IPCONFIG_IPCONFIG_H
 
@@ -14,6 +10,9 @@
 extern uint16_t cfg_local_port;
 extern uint16_t cfg_remote_port;
 
+extern char vendor_class_identifier[];
+extern int vendor_class_identifier_len;
+
 int ipconfig_main(int argc, char *argv[]);
 uint32_t ipconfig_server_address(void *next);
 
